@@ -15,25 +15,21 @@ You should have received a copy of the GNU Affero General Public License
 along with nucypher.  If not, see <https://www.gnu.org/licenses/>.
 """
 
-from copy import copy
+
 import tempfile
+from copy import copy
 from unittest.mock import patch
 
 from eth_tester.exceptions import ValidationError
 
+from nucypher.blockchain.eth.signers.software import Web3Signer
 from nucypher.characters.lawful import Alice, Ursula
 from nucypher.config.constants import TEMPORARY_DOMAIN
 from nucypher.crypto.api import encrypt_and_sign
-from nucypher.crypto.constants import HRAC_LENGTH
 from nucypher.crypto.powers import CryptoPower, SigningPower, DecryptingPower, TransactingPower
 from nucypher.exceptions import DevelopmentInstallationRequired
 from nucypher.policy.collections import SignedTreasureMap
 
-try:
-    from tests.utils.middleware import EvilMiddleWare
-except ImportError:
-    pass  # TODO: #2000 Handle this situation with a common Exception
-
 
 class Vladimir(Ursula):
     """
@@ -61,6 +57,7 @@ class Vladimir(Ursula):
         """
         try:
             from tests.utils.middleware import EvilMiddleWare
+            from tests.constants import MOCK_PROVIDER_URI
         except ImportError:
             raise DevelopmentInstallationRequired(importable_name='tests.utils.middleware.EvilMiddleWare')
         cls.network_middleware = EvilMiddleWare()
@@ -70,8 +67,9 @@ class Vladimir(Ursula):
         if claim_signing_key:
             crypto_power.consume_power_up(SigningPower(public_key=target_ursula.stamp.as_umbral_pubkey()))
 
+        blockchain = target_ursula.policy_agent.blockchain
         if attach_transacting_key:
-            cls.attach_transacting_key(blockchain=target_ursula.policy_agent.blockchain)
+            cls.attach_transacting_key(blockchain=blockchain)
 
         db_filepath = tempfile.mkdtemp(prefix='Vladimir')
 
@@ -79,14 +77,14 @@ class Vladimir(Ursula):
                        crypto_power=crypto_power,
                        db_filepath=db_filepath,
                        domain=TEMPORARY_DOMAIN,
-                       block_until_ready=False,
-                       commit_now=False,
                        rest_host=target_ursula.rest_interface.host,
                        rest_port=target_ursula.rest_interface.port,
-                       certificate=target_ursula.rest_server_certificate(),
+                       certificate=target_ursula.certificate,
                        network_middleware=cls.network_middleware,
                        checksum_address=cls.fraud_address,
                        worker_address=cls.fraud_address,
+                       signer=Web3Signer(blockchain.client),
+                       provider_uri=blockchain.provider_uri,
                        ######### Asshole.
                        timestamp=target_ursula._timestamp,
                        interface_signature=target_ursula._interface_signature,
@@ -186,7 +184,7 @@ class Amonia(Alice):
         def publish_wrong_payee_address_to_blockchain(policy, _ursulas):
             receipt = policy.alice.policy_agent.create_policy(
                 policy_id=policy.hrac,  # bytes16 _policyID
-                author_address=policy.alice.checksum_address,
+                transacting_power=policy.alice.transacting_power,
                 value=policy.value,
                 end_timestamp=policy.expiration.epoch,  # uint16 _numberOfPeriods
                 node_addresses=[f.checksum_address for f in ursulas_to_pay_instead]  # address[] memory _nodes
