@@ -32,7 +32,7 @@ from nucypher.cli.actions.configure import get_or_update_configuration, handle_m
 from nucypher.cli.actions.confirm import (
     confirm_enable_restaking,
     confirm_enable_winding_down,
-    confirm_large_stake,
+    confirm_large_and_or_long_stake,
     confirm_staged_stake,
     confirm_disable_snapshots
 )
@@ -92,7 +92,9 @@ from nucypher.cli.literature import (
     CONFIRM_STAKE_USE_UNLOCKED,
     CONFIRM_REMOVE_ALL_INACTIVE_SUBSTAKES,
     NO_INACTIVE_STAKES,
-    FETCHING_INACTIVE_STAKES
+    FETCHING_INACTIVE_STAKES,
+    MIGRATION_ALREADY_PERFORMED,
+    CONFIRM_MANUAL_MIGRATION
 )
 from nucypher.cli.options import (
     group_options,
@@ -366,13 +368,19 @@ def bond_worker(general_config: GroupGeneralConfig,
     emitter = setup_emitter(general_config)
     STAKEHOLDER = transacting_staker_options.create_character(emitter, config_file)
     blockchain = transacting_staker_options.get_blockchain()
-    economics = STAKEHOLDER.staker.economics
 
     client_account, staking_address = select_client_account_for_staking(
         emitter=emitter,
         stakeholder=STAKEHOLDER,
         staking_address=transacting_staker_options.staker_options.staking_address)
 
+    password = get_password(stakeholder=STAKEHOLDER,
+                            blockchain=blockchain,
+                            client_account=client_account,
+                            hw_wallet=transacting_staker_options.hw_wallet)
+    STAKEHOLDER.assimilate(checksum_address=client_account, password=password)
+    economics = STAKEHOLDER.staker.economics
+
     if not worker_address:
         worker_address = click.prompt(PROMPT_WORKER_ADDRESS, type=EIP55_CHECKSUM_ADDRESS)
 
@@ -397,11 +405,6 @@ def bond_worker(general_config: GroupGeneralConfig,
                       f"worker {worker_address} to staker {staking_address} "
                       f"for a minimum of {STAKEHOLDER.staker.economics.minimum_worker_periods} periods?", abort=True)
 
-    password = get_password(stakeholder=STAKEHOLDER,
-                            blockchain=blockchain,
-                            client_account=client_account,
-                            hw_wallet=transacting_staker_options.hw_wallet)
-    STAKEHOLDER.assimilate(checksum_address=client_account, password=password)
     receipt = STAKEHOLDER.staker.bond_worker(worker_address=worker_address)
 
     # Report Success
@@ -431,8 +434,6 @@ def unbond_worker(general_config: GroupGeneralConfig,
     STAKEHOLDER = transacting_staker_options.create_character(emitter, config_file)
     blockchain = transacting_staker_options.get_blockchain()
 
-    economics = STAKEHOLDER.staker.economics
-
     client_account, staking_address = select_client_account_for_staking(
         emitter=emitter,
         stakeholder=STAKEHOLDER,
@@ -450,6 +451,7 @@ def unbond_worker(general_config: GroupGeneralConfig,
         click.confirm("Are you sure you want to unbond your worker?", abort=True)
 
     STAKEHOLDER.assimilate(checksum_address=client_account, password=password)
+    economics = STAKEHOLDER.staker.economics
     receipt = STAKEHOLDER.staker.unbond_worker()
 
     # TODO: Double-check dates
@@ -545,7 +547,7 @@ def create(general_config: GroupGeneralConfig,
     #
 
     if not force:
-        confirm_large_stake(value=value, lock_periods=lock_periods)
+        confirm_large_and_or_long_stake(value=value, lock_periods=lock_periods, economics=economics)
         paint_staged_stake(emitter=emitter,
                            blockchain=blockchain,
                            stakeholder=STAKEHOLDER,
@@ -634,7 +636,7 @@ def increase(general_config: GroupGeneralConfig,
         current_period = STAKEHOLDER.staker.staking_agent.get_current_period()
         unlock_period = current_stake.final_locked_period + 1
 
-        confirm_large_stake(value=value, lock_periods=lock_periods)
+        confirm_large_and_or_long_stake(value=value, lock_periods=lock_periods, economics=STAKEHOLDER.staker.economics)
         paint_staged_stake(emitter=emitter,
                            blockchain=blockchain,
                            stakeholder=STAKEHOLDER,
@@ -878,7 +880,7 @@ def divide(general_config: GroupGeneralConfig,
         extension = lock_periods
 
     if not force:
-        confirm_large_stake(lock_periods=extension, value=value)
+        confirm_large_and_or_long_stake(lock_periods=extension, value=value, economics=economics)
         paint_staged_stake_division(emitter=emitter,
                                     blockchain=blockchain,
                                     stakeholder=STAKEHOLDER,
@@ -1063,7 +1065,6 @@ def remove_inactive(general_config: GroupGeneralConfig,
     # Setup
     emitter = setup_emitter(general_config)
     STAKEHOLDER = transacting_staker_options.create_character(emitter, config_file)
-    action_period = STAKEHOLDER.staker.staking_agent.get_current_period()
     blockchain = transacting_staker_options.get_blockchain()
 
     client_account, staking_address = select_client_account_for_staking(
@@ -1071,13 +1072,13 @@ def remove_inactive(general_config: GroupGeneralConfig,
         stakeholder=STAKEHOLDER,
         staking_address=transacting_staker_options.staker_options.staking_address)
 
-
     # Authenticate
     password = get_password(stakeholder=STAKEHOLDER,
                             blockchain=blockchain,
                             client_account=client_account,
                             hw_wallet=transacting_staker_options.hw_wallet)
     STAKEHOLDER.assimilate(checksum_address=client_account, password=password)
+    action_period = STAKEHOLDER.staker.staking_agent.get_current_period()
 
     emitter.message(FETCHING_INACTIVE_STAKES, color='yellow')
     if remove_all:
@@ -1102,7 +1103,7 @@ def remove_inactive(general_config: GroupGeneralConfig,
         if index is not None:  # 0 is valid.
             selected_stake = STAKEHOLDER.staker.stakes[index]
         else:
-            selected_stake = select_stake(staker=STAKEHOLDER, emitter=emitter, stakes_status=Stake.Status.INACTIVE)
+            selected_stake = select_stake(staker=STAKEHOLDER.staker, emitter=emitter, stakes_status=Stake.Status.INACTIVE)
 
         remove_inactive_substake(emitter=emitter,
                                  stakeholder=STAKEHOLDER,
@@ -1349,3 +1350,52 @@ def mint(general_config: GroupGeneralConfig,
                           emitter=emitter,
                           chain_name=blockchain.client.chain_name,
                           transaction_type='mint')
+
+
+@stake.command()
+@group_transacting_staker_options
+@option_config_file
+@option_force
+@group_general_config
+@click.option('--external-staker-address',
+              help="The staking address to manually migrate (defaults to wallet address)", type=EIP55_CHECKSUM_ADDRESS)
+def migrate(general_config: GroupGeneralConfig,
+            transacting_staker_options: TransactingStakerOptions,
+            config_file,
+            force,
+            external_staker_address):
+    """
+    Manually migrate a staker to updated period duration. Stakers do not normally need to run
+    this command unless there is a problem with automated migration or commitments.
+    """
+
+    # Setup
+    emitter = setup_emitter(general_config)
+    STAKEHOLDER = transacting_staker_options.create_character(emitter, config_file)
+    blockchain = transacting_staker_options.get_blockchain()
+    client_account, staking_address = select_client_account_for_staking(
+        emitter=emitter,
+        stakeholder=STAKEHOLDER,
+        staking_address=transacting_staker_options.staker_options.staking_address)
+
+    # Interact
+    address_to_migrate = external_staker_address or staking_address
+    if STAKEHOLDER.staker.is_migrated:
+        emitter.echo(MIGRATION_ALREADY_PERFORMED.format(address=address_to_migrate), color='red')
+        raise click.Abort
+    if not force:
+        click.confirm(CONFIRM_MANUAL_MIGRATION.format(address=address_to_migrate), abort=True)
+
+    # Authenticate
+    password = get_password(stakeholder=STAKEHOLDER,
+                            blockchain=blockchain,
+                            client_account=client_account,
+                            hw_wallet=transacting_staker_options.hw_wallet)
+    STAKEHOLDER.assimilate(checksum_address=client_account, password=password)
+
+    # Migrate
+    receipt = STAKEHOLDER.staker.migrate(staker_address=address_to_migrate)
+    paint_receipt_summary(receipt=receipt,
+                          emitter=emitter,
+                          chain_name=blockchain.client.chain_name,
+                          transaction_type='migrate')
