@@ -326,12 +326,13 @@ class Policy(ABC):
 
         if len(accepted_arrangements) < self.n:
 
-            rejected_proposals = "\n".join(f"{address}: {exception}" for address, exception in failures.items())
+            rejected_proposals = "\n".join(f"{address}: {value}" for address, (type_, value, traceback) in failures.items())
 
             self.log.debug(
                 "Could not find enough Ursulas to accept proposals.\n"
                 f"Accepted: {accepted_addresses}\n"
                 f"Rejected:\n{rejected_proposals}")
+
             raise self._not_enough_ursulas_exception()
         else:
             self.log.debug(f"Finished proposing arrangements; accepted: {accepted_addresses}")
@@ -576,11 +577,12 @@ class BlockchainPolicy(Policy):
             raise BlockchainPolicy.InvalidPolicyValue(f"Negative policy parameters are not allowed. Be positive.")
 
         # Check for policy params
-        if not bool(value) ^ bool(rate):
-            # TODO: Review this suggestion
-            raise BlockchainPolicy.InvalidPolicyValue(f"Either 'value' or 'rate'  must be provided for policy.")
+        if not (bool(value) ^ bool(rate)):
+            if not (value == 0 or rate == 0):  # Support a min fee rate of 0
+                raise BlockchainPolicy.InvalidPolicyValue(f"Either 'value' or 'rate'  must be provided for policy. "
+                                                          f"Got value: {value} and rate: {rate}")
 
-        if not value:
+        if value is None:
             value = rate * duration_periods * n
 
         else:
@@ -615,7 +617,7 @@ class BlockchainPolicy(Policy):
         # Transact  # TODO: Move this logic to BlockchainPolicyActor
         receipt = self.alice.policy_agent.create_policy(
             policy_id=self.hrac,  # bytes16 _policyID
-            author_address=self.alice.checksum_address,
+            transacting_power=self.alice.transacting_power,
             value=self.value,
             end_timestamp=self.expiration.epoch,  # uint16 _numberOfPeriods
             node_addresses=addresses  # address[] memory _nodes
